﻿/*
 * Copyright (C)  2011  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.IO;
using System.Drawing;
using System.Diagnostics;
using System.Windows.Forms;

namespace plexdata.ClipboardViewer
{
    internal class ImageViewer : Panel
    {
        private ImageViewerBox viewer = null;

        public ImageViewer()
            : base()
        {
            this.BackColor = SystemColors.Window;
            this.AutoScroll = true;

            this.viewer = new ImageViewerBox();
            this.viewer.BorderStyle = BorderStyle.None;
            this.viewer.Dock = DockStyle.Fill;
            this.viewer.SizeMode = PictureBoxSizeMode.CenterImage;

            this.Controls.Add(this.viewer);
        }

        public void SetImage(Image image)
        {
            this.viewer.Image = image;

            if (this.viewer.Image != null)
            {
                this.AutoScrollMinSize = this.viewer.Image.Size;
            }
            else
            {
                this.AutoScrollMinSize = new Size();
            }
        }

        private class ImageViewerBox : PictureBox
        {
            public ImageViewerBox()
                : base()
            {
                this.SetStyle(ControlStyles.DoubleBuffer, true);
                this.SetStyle(ControlStyles.ResizeRedraw, true);
            }

            protected override void OnPaint(PaintEventArgs args)
            {
                base.OnPaint(args);

                if (this.Image == null)
                {
                    using (Pen pen = new Pen(Color.Red, 5f))
                    {
                        Rectangle client = this.ClientRectangle;
                        client.Inflate(-20, -20);

                        args.Graphics.DrawLine(
                            pen,
                            new Point(client.X, client.Y),
                            new Point(client.Right, client.Bottom));

                        args.Graphics.DrawLine(
                            pen,
                            new Point(client.X, client.Bottom),
                            new Point(client.Right, client.Y));
                    }
                }
            }
        }
    }
}

// EOF